@@ -1,6 +1,7 @@
 from __future__ import with_statement
 
 from .base import TestCase
+from flask import json
 from flask import Flask, render_template
 from flask_wtf import Form
 from flask_wtf.recaptcha import RecaptchaField
@@ -32,33 +33,35 @@ class TestRecaptcha(TestCase):
 
     def test_recaptcha(self):
         response = self.client.get('/')
-        assert b'//www.google.com/recaptcha/api/' in response.data
-
+        assert b'//www.google.com/recaptcha/api.js' in response.data
 
     def test_invalid_recaptcha(self):
         response = self.client.post('/', data={})
-        assert b'Invalid word' in response.data
+        assert b'missing' in response.data
 
     def test_send_recaptcha_request(self):
         response = self.client.post('/', data={
-            'recaptcha_challenge_field': 'test',
-            'recaptcha_response_field': 'test'
+            'g-recaptcha-response': 'test'
         })
-        assert b'Invalid word' in response.data
+        assert b'invalid' in response.data
+
+        response = self.client.post('/', data=json.dumps({
+            'g-recaptcha-response': 'test'
+        }), content_type='application/json')
+        assert b'invalid' in response.data
 
     def test_testing(self):
         self.app.testing = True
         response = self.client.post('/', data={
-            'recaptcha_challenge_field': 'test',
-            'recaptcha_response_field': 'test'
+            'g-recaptcha-response': 'test'
         })
-        assert b'Invalid word' not in response.data
+        assert b'invalid' not in response.data
 
     def test_no_private_key(self):
+        self.app.testing = False
         self.app.config.pop('RECAPTCHA_PRIVATE_KEY', None)
         response = self.client.post('/', data={
-            'recaptcha_challenge_field': 'test',
-            'recaptcha_response_field': 'test'
+            'g-recaptcha-response': 'test'
         })
         assert response.status_code == 500
 
